@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 import requests
 from rich import print
 from rich.prompt import Prompt
@@ -8,6 +6,7 @@ from rich.panel import Panel
 from bs4 import BeautifulSoup
 import socket
 from webhawk.src.dependencies.subdomain.subdomains import subfinder
+from webhawk.src.dependencies.cmsdetector.cmsdetector import scan
 import json
 
 
@@ -38,7 +37,11 @@ def basic_scan(domain):
     except Exception as err:
         print("[[bold yellow]+[/bold yellow]] [bold cyan]Server[/bold cyan]: [bold red]Not Detected[/bold red]")
 
-    print("[[bold yellow]+[/bold yellow]] [bold cyan]CMS[/bold cyan]: [bold red]Could Not Detect[/bold red]")
+    cms = scan(url)
+    if (cms != None):
+        print("[[bold yellow]+[/bold yellow]] [bold cyan]CMS[/bold cyan]: [bold green]{}[/bold green]".format(cms))
+    else:
+        print("[[bold yellow]+[/bold yellow]] [bold cyan]CMS[/bold cyan]: [bold red]Not Detected[/bold red]")
     rreq = requests.get(url+'/robots.txt')
     if(rreq.status_code != 404):
         print("[[bold yellow]+[/bold yellow]] [bold cyan]Robots.txt[/bold cyan]: [bold green]Found[/bold green]")
